@@ -166,7 +166,11 @@ _clutter_backend_gdk_post_parse (ClutterBackend  *backend,
 
   /* Init Gdk, if outside code did not already */
   if (!gdk_init_check (NULL, NULL))
-    return FALSE;
+    {
+      g_set_error (error, CLUTTER_INIT_ERROR, CLUTTER_INIT_ERROR_BACKEND,
+                   _("Could not initialize Gdk"));
+      return FALSE;
+    }
 
   /*
    * Only open connection if not already set by prior call to
@@ -291,6 +295,7 @@ clutter_backend_gdk_get_renderer (ClutterBackend  *backend,
       /* Force a Wayland winsys */
       cogl_renderer_set_winsys_id (renderer, COGL_WINSYS_ID_EGL_WAYLAND);
       cogl_wayland_renderer_set_foreign_display (renderer, display);
+      cogl_wayland_renderer_set_event_dispatch_enabled (renderer, !disable_event_retrieval);
     }
   else
 #endif
